.. currentmodule:: abjad.tools.pitchtools

inventory_named_inversion_equivalent_interval_classes
=====================================================

.. autofunction:: inventory_named_inversion_equivalent_interval_classes
